@@ -21,12 +21,14 @@ OC.L10N.register(
     "Display name" : "Nume afișat",
     "Save" : "Salvează",
     "Close" : "Închide",
+    "Folder" : "Folder",
     "Create" : "Creează",
     "Invalid image" : "Imagine invalidă",
     "Address book" : "Listă de contacte",
     "Name" : "Nume",
     "Title" : "Titlu",
     "Company" : "Companie",
+    "Move" : "Move",
     "No results" : "Niciun rezultat",
     "Pending" : "În așteptare",
     "None" : "Niciuna",
